@@ -2,7 +2,7 @@ package Array::Heap::ModifiablePriorityQueue;
 use strict;
 use warnings;
 use vars qw( $VERSION );
-$VERSION = '1.01';
+$VERSION = '1.10';
 use Array::Heap qw( adjust_heap_idx make_heap_idx pop_heap_idx push_heap_idx
    splice_heap_idx );
 
@@ -133,6 +133,18 @@ sub weight {
    return $node->[0];
 }
 
+=item $pq->min_weight($item)
+
+Returns the minimum weight from the queue, or undef if empty.
+
+=cut
+
+sub min_weight {
+   my ($self) = @_;
+   my $node = $self->{heap}[0] or return;
+   return $node->[0];
+}
+
 =item $pq->size()
 
 Returns the number of items in the priority queue.
@@ -223,11 +235,15 @@ sub restore_order {
 
 =head1 PERFORMANCE
 
-The peek function runs in constant time, or O(1) in asymptotic notation.
-The structure-modifying functions add, get, and remove run in O(log n) time.
+The peek and weight functions run in constant time, or O(1) in asymptotic
+notation. The structure-modifying functions add, get, and remove run in
+O(log n) time. The items function is O(n), and sorted_items is O(n log n).
 Add_unordered and remove_unordered are O(1), but after a sequence of
 unordered operations, you need to call restore_order, which is O(n).
 
+If you don't need the modifiable features of this module, consider using
+L<Array::Heap::PriorityQueue::Numeric> instead.
+
 If you feel that you need maximum speed, go ahead and inline these
 methods into your own code to avoid an extra method invocation. They
 are all quite short and simple.
